@@ -54,7 +54,6 @@ import tensorflow as tf
 from tensorflow.python.feature_column import feature_column as feature_column_v1
 from tensorflow.python.feature_column import feature_column_v2
 from tensorflow.python.framework import ops
-from tensorflow.python.keras.utils import losses_utils
 from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import estimator
 from tensorflow_estimator.python.estimator.canned import head as head_lib
@@ -235,7 +234,7 @@ def _baseline_model_fn_v2(
     optimizer,
     weight_column=None,
     config=None,
-    loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE):
+    loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE):
   """Model_fn for baseline models.
 
   Args:
@@ -276,8 +275,10 @@ def _baseline_model_fn_v2(
 
   def train_op_fn(loss):
     # Scale loss by number of replicas.
-    if loss_reduction == losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE:
-      loss = losses_utils.scale_loss_for_distribution(loss)
+    if loss_reduction == tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE:
+      num_replicas = tf.distribute.get_strategy().num_replicas_in_sync
+      if num_replicas > 1:
+        loss *= (1. / num_replicas)
     return opt.get_updates(loss, trainable_variables)[0]
 
   return head.create_estimator_spec(
@@ -349,7 +350,7 @@ class BaselineClassifierV2(estimator.EstimatorV2):
                label_vocabulary=None,
                optimizer='Ftrl',
                config=None,
-               loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE):
+               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE):
     """Initializes a BaselineClassifier instance.
 
     Args:
@@ -581,7 +582,7 @@ class BaselineRegressorV2(estimator.EstimatorV2):
                weight_column=None,
                optimizer='Ftrl',
                config=None,
-               loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE):
+               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE):
     """Initializes a BaselineRegressor instance.
 
     Args:
