@@ -21,8 +21,6 @@ from __future__ import print_function
 import tensorflow as tf
 
 from tensorflow.python.framework import ops
-from tensorflow.python.keras import metrics
-from tensorflow.python.keras.utils import losses_utils
 from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import model_fn
 from tensorflow_estimator.python.estimator.canned import metric_keys
@@ -136,7 +134,7 @@ class RegressionHead(base_head.Head):
   def __init__(self,
                label_dimension=1,
                weight_column=None,
-               loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
                loss_fn=None,
                inverse_link_fn=None,
                name=None):
@@ -216,7 +214,7 @@ class RegressionHead(base_head.Head):
       labels = self._processed_labels(logits, labels)
       unweighted_loss, weights = self._unweighted_loss_and_weights(
           logits, labels, features)
-      training_loss = losses_utils.compute_weighted_loss(
+      training_loss = tf.compat.v2.keras.__internal__.losses.compute_weighted_loss(
           unweighted_loss,
           sample_weight=weights,
           reduction=self._loss_reduction)
@@ -258,13 +256,15 @@ class RegressionHead(base_head.Head):
     with ops.name_scope('metrics', values=(regularization_losses,)):
       keys = metric_keys.MetricKeys
       eval_metrics = {}
-      eval_metrics[self._loss_mean_key] = metrics.Mean(name=keys.LOSS_MEAN)
-      eval_metrics[self._prediction_mean_key] = metrics.Mean(
+      eval_metrics[self._loss_mean_key] = tf.keras.metrics.Mean(
+          name=keys.LOSS_MEAN)
+      eval_metrics[self._prediction_mean_key] = tf.keras.metrics.Mean(
           name=keys.PREDICTION_MEAN)
-      eval_metrics[self._label_mean_key] = metrics.Mean(name=keys.LABEL_MEAN)
+      eval_metrics[self._label_mean_key] = tf.keras.metrics.Mean(
+          name=keys.LABEL_MEAN)
 
       if regularization_losses is not None:
-        eval_metrics[self._loss_regularization_key] = metrics.Mean(
+        eval_metrics[self._loss_regularization_key] = tf.keras.metrics.Mean(
             name=keys.LOSS_REGULARIZATION)
     return eval_metrics
 
@@ -477,7 +477,7 @@ class PoissonRegressionHead(RegressionHead):
   def __init__(self,
                label_dimension=1,
                weight_column=None,
-               loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
                compute_full_loss=True,
                name=None):
     self._compute_full_loss = compute_full_loss
@@ -572,7 +572,7 @@ class LogisticRegressionHead(RegressionHead):
 
   def __init__(self,
                weight_column=None,
-               loss_reduction=losses_utils.ReductionV2.SUM_OVER_BATCH_SIZE,
+               loss_reduction=tf.compat.v2.keras.losses.Reduction.SUM_OVER_BATCH_SIZE,
                name=None):
     super(LogisticRegressionHead, self).__init__(
         label_dimension=1,
