@@ -24,34 +24,25 @@ import os
 
 import six
 import tensorflow as tf
-from tensorflow.core.protobuf import config_pb2
 from tensorflow.core.protobuf import rewriter_config_pb2
 from tensorflow.python.distribute import estimator_training as distribute_coordinator_training
 from tensorflow.python.util import compat_internal
 from tensorflow.python.util import function_utils
 from tensorflow.python.util.tf_export import estimator_export
 
+
 _USE_DEFAULT = object()
 _VALID_DEVICE_FN_ARGS = set(['op'])
 
 # A list of the property names in RunConfig that the user is allowed to change.
 _DEFAULT_REPLACEABLE_LIST = [
-    'model_dir',
-    'tf_random_seed',
-    'save_summary_steps',
-    'save_checkpoints_steps',
-    'save_checkpoints_secs',
-    'session_config',
-    'keep_checkpoint_max',
-    'keep_checkpoint_every_n_hours',
-    'log_step_count_steps',
-    'train_distribute',
-    'device_fn',
-    'protocol',
-    'eval_distribute',
-    'experimental_distribute',
-    'experimental_max_worker_delay_secs',
-    'session_creation_timeout_secs',
+    'model_dir', 'tf_random_seed', 'save_summary_steps',
+    'save_checkpoints_steps', 'save_checkpoints_secs', 'session_config',
+    'keep_checkpoint_max', 'keep_checkpoint_every_n_hours',
+    'log_step_count_steps', 'train_distribute', 'device_fn', 'protocol',
+    'eval_distribute', 'experimental_distribute',
+    'experimental_max_worker_delay_secs', 'session_creation_timeout_secs',
+    'checkpoint_save_graph_def'
 ]
 
 _SAVE_CKPT_ERR = (
@@ -287,7 +278,7 @@ def _validate_properties(run_config):
 
   _validate(
       'session_config',
-      lambda sc: isinstance(sc, config_pb2.ConfigProto),
+      lambda sc: isinstance(sc, tf.compat.v1.ConfigProto),
       message='session_config must be instance of ConfigProto')
 
   _validate(
@@ -336,9 +327,9 @@ def get_default_session_config():
 
   rewrite_opts = rewriter_config_pb2.RewriterConfig(
       meta_optimizer_iterations=rewriter_config_pb2.RewriterConfig.ONE)
-  graph_opts = config_pb2.GraphOptions(rewrite_options=rewrite_opts)
+  graph_opts = tf.compat.v1.GraphOptions(rewrite_options=rewrite_opts)
 
-  return config_pb2.ConfigProto(
+  return tf.compat.v1.ConfigProto(
       allow_soft_placement=True, graph_options=graph_opts)
 
 
@@ -370,7 +361,8 @@ class RunConfig(object):
                eval_distribute=None,
                experimental_distribute=None,
                experimental_max_worker_delay_secs=None,
-               session_creation_timeout_secs=7200):
+               session_creation_timeout_secs=7200,
+               checkpoint_save_graph_def=True):
     """Constructs a RunConfig.
 
     All distributed training related properties `cluster_spec`, `is_chief`,
@@ -529,6 +521,10 @@ class RunConfig(object):
         with MonitoredTrainingSession. Defaults to 7200 seconds, but users may
         want to set a lower value to detect problems with variable / session
         (re)-initialization more quickly.
+      checkpoint_save_graph_def: Whether to save the GraphDef and MetaGraphDef
+        to `checkpoint_dir`. The GraphDef is saved after the session is created
+        as `graph.pbtxt`. MetaGraphDefs are saved out for every checkpoint as
+        `model.ckpt-*.meta`.
 
     Raises:
       ValueError: If both `save_checkpoints_steps` and `save_checkpoints_secs`
@@ -546,6 +542,8 @@ class RunConfig(object):
           save_checkpoints_secs is not None):
       raise ValueError(_SAVE_CKPT_ERR)
 
+    self._verify_strategy_compatibility(train_distribute, eval_distribute)
+
     tf_config = json.loads(os.environ.get(_TF_CONFIG_ENV, '{}'))
     if tf_config:
       tf.compat.v1.logging.info('TF_CONFIG environment variable: %s', tf_config)
@@ -571,7 +569,8 @@ class RunConfig(object):
         eval_distribute=eval_distribute,
         experimental_distribute=experimental_distribute,
         experimental_max_worker_delay_secs=experimental_max_worker_delay_secs,
-        session_creation_timeout_secs=session_creation_timeout_secs)
+        session_creation_timeout_secs=session_creation_timeout_secs,
+        checkpoint_save_graph_def=checkpoint_save_graph_def)
 
     # TODO(frankchn,priyag): Eventually use distributed coordinator for TPUs.
     if ((train_distribute and
@@ -586,6 +585,15 @@ class RunConfig(object):
       self._init_distributed_setting_from_environment_var(tf_config)
       self._maybe_overwrite_session_config_for_distributed_training()
 
+  def _verify_strategy_compatibility(self, train_distribute, eval_distribute):
+    if ((train_distribute is not None and train_distribute.__class__ ==
+         tf.compat.v2.distribute.experimental.ParameterServerStrategy) or
+        (eval_distribute is not None and eval_distribute.__class__ ==
+         tf.compat.v2.distribute.experimental.ParameterServerStrategy)):
+      raise ValueError('Please use `tf.compat.v1.distribute.experimental.Param'
+                       'eterServerStrategy` for parameter server strategy with '
+                       'estimator.')
+
   def _maybe_overwrite_session_config_for_distributed_training(self):
     """Overwrites the session_config for distributed training.
 
@@ -609,7 +617,7 @@ class RunConfig(object):
 
     rewrite_opts = rewriter_config_pb2.RewriterConfig(
         meta_optimizer_iterations=rewriter_config_pb2.RewriterConfig.ONE)
-    graph_opts = config_pb2.GraphOptions(rewrite_options=rewrite_opts)
+    graph_opts = tf.compat.v1.GraphOptions(rewrite_options=rewrite_opts)
 
     device_filters = None
     if self._task_type == TaskType.MASTER:
@@ -625,7 +633,7 @@ class RunConfig(object):
       # TaskType then don't set any device filters.
       return None
 
-    return config_pb2.ConfigProto(
+    return tf.compat.v1.ConfigProto(
         allow_soft_placement=True,
         graph_options=graph_opts,
         device_filters=device_filters)
@@ -830,6 +838,10 @@ class RunConfig(object):
   def save_checkpoints_steps(self):
     return self._save_checkpoints_steps
 
+  @property
+  def checkpoint_save_graph_def(self):
+    return self._checkpoint_save_graph_def
+
   @property
   def keep_checkpoint_max(self):
     return self._keep_checkpoint_max
