@@ -25,13 +25,15 @@ from tensorflow.python.feature_column import feature_column as core_fc
 from tensorflow.python.feature_column import feature_column_lib as core_fc_lib
 from tensorflow.python.feature_column import utils as fc_utils
 from tensorflow.python.framework import ops
-from tensorflow.python.ops import sparse_ops
 from tensorflow.python.tpu import feature_column as tpu_fc
 from tensorflow.python.tpu import feature_column_v2 as tpu_fc_v2
 from tensorflow.python.tpu import tpu_embedding
 from tensorflow.python.tpu.tpu_embedding import AdagradParameters
 from tensorflow.python.tpu.tpu_embedding import AdamParameters
 from tensorflow.python.tpu.tpu_embedding import FtrlParameters
+from tensorflow.python.tpu.tpu_embedding import MomentumParameters
+from tensorflow.python.tpu.tpu_embedding import ProximalAdagradParameters
+from tensorflow.python.tpu.tpu_embedding import RMSPropParameters
 from tensorflow.python.tpu.tpu_embedding import StochasticGradientDescentParameters
 from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import model_fn as model_fn_lib
@@ -48,8 +50,16 @@ _EMBEDDING_COLUMN_CLASSES = (core_fc._EmbeddingColumn,
                              core_fc_lib.EmbeddingColumn,
                              core_fc._SharedEmbeddingColumn)
 _SUPPORTED_FEATURE_COLUMNS = (core_fc._NumericColumn, core_fc_lib.NumericColumn)
-_SUPPORTED_OPTIMIZERS = (AdagradParameters, AdamParameters, FtrlParameters,
-                         StochasticGradientDescentParameters)
+
+_SUPPORTED_OPTIMIZERS = (
+    ProximalAdagradParameters,
+    AdagradParameters,
+    AdamParameters,
+    FtrlParameters,
+    StochasticGradientDescentParameters,
+    MomentumParameters,
+    RMSPropParameters,
+)
 
 # pylint: enable=protected-access
 
@@ -89,6 +99,18 @@ def _get_slot_variable_names(scope_name, var_name, optimization_parameters):
     return tpu_embedding.FtrlSlotVariableName(
         '{}{}/Ftrl'.format(scope_name, var_name),  # accumulator
         '{}{}/Ftrl_1'.format(scope_name, var_name))  # linear
+  elif isinstance(optimization_parameters, MomentumParameters):
+    return tpu_embedding.MomentumSlotVariableName('{}{}/Momentum'.format(
+        scope_name, var_name))
+  elif isinstance(optimization_parameters, RMSPropParameters):
+    return tpu_embedding.RMSPropSlotVariableNames(
+        ms='{}{}/RMSProp/ms'.format(scope_name, var_name),
+        mom='{}{}/RMSProp/mom'.format(scope_name, var_name),
+    )
+  elif isinstance(optimization_parameters, ProximalAdagradParameters):
+    return tpu_embedding.ProximalAdagradSlotVariableName(
+        '{}{}/ProximalAdagrad'.format(scope_name, var_name)
+    )
   elif isinstance(
       optimization_parameters,
       tf.compat.v1.tpu.experimental.StochasticGradientDescentParameters):
@@ -184,7 +206,7 @@ class EmbeddingConfigSpec(
         'optimization_parameters', 'clipping_limit',
         'pipeline_execution_with_tensor_core',
         'experimental_gradient_multiplier_fn', 'feature_to_config_dict',
-        'table_to_config_dict', 'partition_strategy'
+        'table_to_config_dict', 'partition_strategy', 'profile_data_directory'
     ])):
   """Class to keep track of the specification for TPU embeddings.
 
@@ -224,6 +246,14 @@ class EmbeddingConfigSpec(
           column=tpu_columns,
           optimization_parameters=(
               tf.estimator.tpu.experimental.AdagradParameters(0.1))))
+  ```
+
+  @compatibility(TF2)
+  TPU Estimator manages its own TensorFlow graph and session, so it is not
+  compatible with TF2 behaviors. We recommend that you migrate to the newer
+  `tf.distribute.TPUStrategy`. See the
+  [TPU guide](https://www.tensorflow.org/guide/tpu) for details.
+  @end_compatibility
   """
 
   def __new__(cls,
@@ -234,7 +264,8 @@ class EmbeddingConfigSpec(
               experimental_gradient_multiplier_fn=None,
               feature_to_config_dict=None,
               table_to_config_dict=None,
-              partition_strategy='div'):
+              partition_strategy='div',
+              profile_data_directory=None):
     """Creates an `EmbeddingConfigSpec` instance.
 
     Args:
@@ -250,16 +281,31 @@ class EmbeddingConfigSpec(
         `tpu_embedding_configuration.proto` for details.
       experimental_gradient_multiplier_fn: (Optional) A Fn taking global step as
         input returning the current multiplier for all embedding gradients.
-      feature_to_config_dict: A dictionary mapping features names to instances
-        of the class `FeatureConfig`. Either features_columns or the pair of
+      feature_to_config_dict: A dictionary mapping feature names to instances of
+        the class `FeatureConfig`. Either features_columns or the pair of
         `feature_to_config_dict` and `table_to_config_dict` must be specified.
-      table_to_config_dict: A dictionary mapping features names to instances of
+      table_to_config_dict: A dictionary mapping feature names to instances of
         the class `TableConfig`. Either features_columns or the pair of
         `feature_to_config_dict` and `table_to_config_dict` must be specified.
       partition_strategy: A string, determining how tensors are sharded to the
         tpu hosts. See `tf.nn.safe_embedding_lookup_sparse` for more details.
         Allowed value are `"div"` and `"mod"'. If `"mod"` is used, evaluation
         and exporting the model to CPU will not work as expected.
+      profile_data_directory: Directory where embedding lookup statistics are
+        stored. These statistics summarize information about the inputs to the
+        embedding lookup operation, in particular, the average number of
+        embedding IDs per example and how well the embedding IDs are load
+        balanced across the system. The lookup statistics are used during TPU
+        initialization for embedding table partitioning. Collection of lookup
+        statistics is done at runtime by  profiling the embedding inputs: only
+        3% of input samples are profiled to minimize host CPU overhead. Once
+        a suitable number of samples are profiled, the lookup statistics are
+        saved to table-specific files in the profile data directory generally
+        at the end of a TPU training loop. The filename corresponding to each
+        table is obtained by hashing table specific parameters (e.g., table
+        name and number of features) and global configuration parameters (e.g.,
+        sharding strategy and task count). The same profile data directory can
+        be shared among several models to reuse embedding lookup statistics.
 
     Returns:
       An `EmbeddingConfigSpec` instance.
@@ -336,7 +382,8 @@ class EmbeddingConfigSpec(
         experimental_gradient_multiplier_fn=experimental_gradient_multiplier_fn,
         feature_to_config_dict=feature_to_config_dict,
         table_to_config_dict=table_to_config_dict,
-        partition_strategy=partition_strategy)
+        partition_strategy=partition_strategy,
+        profile_data_directory=profile_data_directory)
 
 
 class EmbeddingConfig(object):
@@ -423,6 +470,8 @@ class EmbeddingConfig(object):
         pipeline_execution_with_tensor_core=self._embedding_config_spec
         .pipeline_execution_with_tensor_core,
         partition_strategy=self._partition_strategy,
+        profile_data_directory=self._embedding_config_spec
+        .profile_data_directory,
         master_job_name=master_job_name)
     return tpu_embedding_
 
@@ -534,7 +583,7 @@ def _split_tensor(tensor, num_splits):
   elif num_splits == 1:
     return [tensor]
   elif isinstance(tensor, tf.sparse.SparseTensor):
-    return sparse_ops.sparse_split_v2(tensor, num_splits, axis=0)
+    return tf.compat.v2.sparse.split(tensor, num_splits, axis=0)
   else:
     return tf.split(tensor, num_splits)
 
