@@ -46,17 +46,55 @@ _NUM_CORES_TO_COMPUTATION_SHAPE = {
 
 
 class TPUContext(object):
-  """A context that holds the current configuration of the TPU computation."""
+  """A context that holds the current configuration of the TPU computation.
+
+  TPUContext was designed for getting TPU context information when calling
+  input_fn. It can be called in model_fn as well.
+
+  User is not expected to construct the instance from constructor. The only
+  legitimate way to get the instance is either in `input_fn`:
+
+  ```
+  def input_fn(params):
+    batch_size = params['batch_size']
+    context = params['context']
+    # ...
+  ```
+
+  or in `model_fn`
+
+  ```
+  def model_fn(params):
+    batch_size = params['batch_size']
+    context = params['context']
+    # ...
+  ```
+
+  Most of the fields of TPUContext are useful for both `input_fn` and
+  `model_fn`. Exceptions are:
+
+  1. `input_fn` only:
+
+    current_input_fn_deployment
+    current_host
+
+  2. `model_fn` only:
+
+    device_assignment
+
+  """
 
   def __init__(self,
                internal_ctx,
                input_device=None,
                invocation_index=None,
-               call_from_input_fn=True):
+               call_from_input_fn=True,
+               host_id=None):
     self._internal_ctx = internal_ctx
     self._input_device = input_device
     self._invocation_index = invocation_index
     self._call_from_input_fn = call_from_input_fn
+    self._host_id = host_id
 
   def current_input_fn_deployment(self):
     """The configuration of the current input_fn invocation.
@@ -86,7 +124,7 @@ class TPUContext(object):
            replicas per host.
 
     Raises:
-      RuntimeError: If this method must not be called from input_fn.
+      RuntimeError: If this method is not be called from input_fn.
     """
     if not self._call_from_input_fn:
       raise RuntimeError('This TPUContext instance must not be called from'
@@ -128,8 +166,20 @@ class TPUContext(object):
 
   @property
   def current_host(self):
-    """The current host index for the TPU system."""
-    return self._invocation_index
+    """The current host index for the TPU system.
+
+    Returns:
+      The host index (int).
+
+    Raises:
+      RuntimeError: If this method is not be called from input_fn.
+    """
+
+    if not self._call_from_input_fn:
+      raise RuntimeError('This TPUContext instance must not be called from'
+                         ' model_fn.')
+
+    return self._host_id
 
   @property
   def num_of_replicas_per_host(self):
@@ -141,7 +191,11 @@ class TPUContext(object):
 
   @property
   def device_assignment(self):
-    """Returns device_assignment object."""
+    """Returns device_assignment object.
+
+    Raises:
+      RuntimeError: If this method is not be called from model_fn.
+    """
     if self._call_from_input_fn:
       raise RuntimeError('This TPUContext instance must not be called from'
                          ' input_fn.')
@@ -343,6 +397,15 @@ class _InternalTPUContext(object):
       embedding_config.tpu_embedding = embedding_config.get_tpu_embedding(mode)
     return embedding_config
 
+  @property
+  def allow_per_host_v2_parallel_get_next(self):
+    return (self._config.tpu_config
+            .experimental_allow_per_host_v2_parallel_get_next)
+
+  @property
+  def feed_hook(self):
+    return (self._config.tpu_config.experimental_feed_hook)
+
   @property
   def model_parallelism_enabled(self):
     return self._model_parallelism_enabled
@@ -689,16 +752,19 @@ class _InternalTPUContext(object):
         raise ValueError(
             'eval batch size {} must be divisible by number of replicas {}'
             .format(self._eval_batch_size, num_replicas))
-      if num_hosts != 1 and not (
-          self.is_input_broadcast_with_iterators()) and not (
-              num_replicas == 1 and self.is_input_per_host_with_iterators()):
+      if (num_hosts != 1 and
+          not self.is_input_broadcast_with_iterators() and
+          not self.is_input_per_host_with_iterators()):
         raise ValueError(
             'TPUEstimator.evaluate is only supported under three conditions: '
             '1. num_hosts=1; 2. BROADCAST mode; '
-            '3. PER_HOST_V2 mode with num_replicas=1. '
+            '3. PER_HOST_V2 mode. '
             'mode: {}; num_hosts: {}; num_replicas=1:{}'.format(
                 self._config.tpu_config.per_host_input_for_training, num_hosts,
                 num_replicas))
+      if num_hosts > 1 and self.is_input_per_host_with_iterators():
+        tf.compat.v1.logging.warn('Running TPUEstimator.evaluate for input mode'
+                                  ' PER_HOST_V2 and num_hosts %d', num_hosts)
     else:
       assert mode == model_fn_lib.ModeKeys.PREDICT
       if self._predict_batch_size is None:
@@ -772,7 +838,7 @@ class _OneCoreTPUContext(_InternalTPUContext):
       return tpu_system_metadata
 
     tpu_system_metadata = (
-        tpu_system_metadata_lib.TPUSystemMetadata(  # pylint: disable=protected-access
+        tf.tpu.experimental.TPUSystemMetadata(  # pylint: disable=protected-access
             num_cores=1,
             num_hosts=1,
             num_of_cores_per_host=1,
@@ -809,7 +875,7 @@ class _TPUEstimatorReplicaContext(tf.distribute.ReplicaContext):
   def __enter__(self):
 
     def replica_id_is_zero():
-      return tf.math.equal(self._replica_id_in_sync_group, tf.constant(0))
+      return tf.math.equal(self.replica_id_in_sync_group, tf.constant(0))
 
     if hasattr(summary_ops_v2, '_summary_state'):
       summary_state = summary_ops_v2._summary_state  # pylint: disable=protected-access
